# SplatFlow

## Original code

[https://github.com/wwsource/SplatFlow](https://github.com/wwsource/SplatFlow)## Additional requirements

In order to use SplatFlow you need to install cupy:

```bash
pip install cupy-cuda12x
```
NOTE: replace "12" by the CUDA version of your PyTorch installation.

## Code license

See [LICENSE](LICENSE).

## Pretrained weights license

Not specified.

## Citation

```
@article{wang2024splatflow,
  title={SplatFlow: Learning Multi-frame Optical Flow via Splatting},
  author={Wang, Bo and Zhang, Yifan and Li, Jian and Yu, Yang and Sun, Zhenping and Liu, Li and Hu, Dewen},
  journal={International Journal of Computer Vision},
  pages={1--23},
  year={2024},
  publisher={Springer}
}
```